ewa.ply.lex.PlyLogger

Package ewa :: Package ply :: Module lex :: Class PlyLogger |
[hide private]
[frames] | no frames]

# Class PlyLogger

source code

    object --+
             |
            PlyLogger

Instance Methods | [hide private]
__init__(self, f) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
critical(self, msg, *args, **kwargs) | source code
warning(self, msg, *args, **kwargs) | source code
error(self, msg, *args, **kwargs) | source code
info(self, msg, *args, **kwargs) | source code
debug(self, msg, *args, **kwargs) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, f) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)